@@ -22,68 +22,66 @@
 
 #include "navigatoritem.h"
 #include "docentry.h"
+#include "khc_debug.h"
 
-#include <KConfig>
 #include <KProcess>
-#include <KConfigGroup>
-#include <KSharedConfig>
 
-#include <QtXml/QtXml>
+#include <QDomDocument>
 #include <QFile>
-#include <QRegExp>
+#include <QStandardPaths>
 
-namespace {
-QLoggingCategory category("org.kde.khelpcenter");
-}
+#include <prefs.h>
 
 using namespace KHC;
 
-ScrollKeeperTreeBuilder::ScrollKeeperTreeBuilder( QObject *parent, const char *name )
+ScrollKeeperTreeBuilder::ScrollKeeperTreeBuilder( QObject *parent )
 	: QObject( parent )
 {
-  setObjectName( name );
-
 	loadConfig();
 }
 
 void ScrollKeeperTreeBuilder::loadConfig()
 {
-  KConfigGroup configGroup( KSharedConfig::openConfig(), "ScrollKeeper" );
-  mShowEmptyDirs = configGroup.readEntry( "ShowEmptyDirs", false);
+  mShowEmptyDirs = Prefs::showEmptyDirs();
 }
 
-NavigatorItem *ScrollKeeperTreeBuilder::build( NavigatorItem *parent,
-                                               NavigatorItem *after )
+void ScrollKeeperTreeBuilder::build( NavigatorItem *parent )
 {
   QString lang = QLocale().bcp47Name();
 
-  qCDebug(category) << "ScrollKeeper language: " << lang;
+  khcDebug() << "ScrollKeeper language: " << lang;
+
+  const QString exePath = QStandardPaths::findExecutable( QLatin1Literal( "scrollkeeper-get-content-list" ) );
+  if ( exePath.isEmpty() ) {
+    khcDebug() << "scrollkeeper-get-content-list is not available, skipping";
+    return;
+  }
 
   KProcess proc;
-  proc << "scrollkeeper-get-content-list";
+  proc << exePath;
   proc << lang;
   
   proc.setOutputChannelMode(KProcess::OnlyStdoutChannel);
   proc.start();
   if ( !proc.waitForFinished() ) {
-    qCDebug(category) << "Could not execute scrollkeeper-get-content-list";
-    return 0;
+    khcWarning() << "Could not execute scrollkeeper-get-content-list";
+    return;
   }
   mContentsList = proc.readAllStandardOutput().trimmed();
 
   if (!QFile::exists(mContentsList)) {
-    qCDebug(category) << "Scrollkeeper contents file '" << mContentsList
-      << "' does not exist." << endl;
-    return 0;
+    khcWarning() << "Scrollkeeper contents file" << mContentsList
+      << "does not exist.";
+    return;
   }
 
   QDomDocument doc("ScrollKeeperContentsList");
   QFile f(mContentsList);
   if ( !f.open( QIODevice::ReadOnly ) )
-    return 0;
+    return;
   if ( !doc.setContent( &f ) ) {
     f.close();
-    return 0;
+    return;
   }
   f.close();
 
@@ -92,32 +90,26 @@ NavigatorItem *ScrollKeeperTreeBuilder::build( NavigatorItem *parent,
 
   QDomElement docElem = doc.documentElement();
 
-  NavigatorItem *result = 0;
-
   QDomNode n = docElem.firstChild();
   while( !n.isNull() ) {
     QDomElement e = n.toElement();
     if( !e.isNull() ) {
       if (e.tagName() == "sect") {
         NavigatorItem *createdItem;
-        insertSection( parent, after, e, createdItem );
-        if ( createdItem ) result = createdItem;
+        insertSection( parent, e, createdItem );
       }
     }
     n = n.nextSibling();
   }
-
-  return result;
 }
 
 int ScrollKeeperTreeBuilder::insertSection( NavigatorItem *parent,
-                                            NavigatorItem *after,
                                             const QDomNode &sectNode,
                                             NavigatorItem *&sectItem )
 {
 // TODO: was contents2 -> needs to be changed to help-contents-alternate or similar
   DocEntry *entry = new DocEntry( "", "", "help-contents" );
-  sectItem = new NavigatorItem( entry, parent, after );
+  sectItem = new NavigatorItem( entry, parent );
   sectItem->setAutoDeleteDocEntry( true );
   mItems.append( sectItem );
 
@@ -132,7 +124,7 @@ int ScrollKeeperTreeBuilder::insertSection( NavigatorItem *parent,
         sectItem->updateItem();
       } else if (e.tagName() == "sect") {
         NavigatorItem *created;
-        numDocs += insertSection( sectItem, 0, e, created );
+        numDocs += insertSection( sectItem, e, created );
       } else if (e.tagName() == "doc") {
         insertDoc(sectItem,e);
         ++numDocs;
